@@ -17,6 +17,10 @@
 #define gv_init_sv(gv, stash, sv, flags) gv_init(gv, stash, SvPVX(sv), SvLEN(sv), flags | SvUTF8(sv))
 #endif
 
+#ifndef GvCV_set
+#define GvCV_set(gv, cv) (GvCV(gv) = cv)
+#endif
+
 #ifndef wrap_op_checker
 #define COMPAT_OP_CHECKER
 #define wrap_op_checker compat_wrap_op_checker
